@@ -3,7 +3,6 @@
 # All Rights Reserved
 #
 import warnings
-import os
 
 
 warnings.filterwarnings(
@@ -20,7 +19,7 @@ warnings.filterwarnings(
     message='^pandas.util.testing is deprecated'
 )
 
-__version__ = '1.16.0'
+__version__ = '1.17.0'
 __product__ = "ihsm-datalake"
 
 
@@ -58,7 +57,7 @@ def connect(
     .. code:: python
 
         import dli
-        client = client.connect()
+        client = dli.connect()
 
     :param str root_url: Optional. The environment you want to point to. By default it
                         points to Production.
