@@ -2,12 +2,10 @@
 # Copyright (C) 2020 IHS Markit.
 # All Rights Reserved
 #
-import warnings
-
-from dli.models.paginator import Paginator
-from dli.client.aspects import analytics_decorator, logging_decorator
-from dli.client.components.urls import dataset_urls
-from dli.models import log_public_functions_calls_using, AttributesDict
+from platform_services_lib.lib.context.urls import dataset_urls
+from platform_services_lib.lib.aspects.decorators import analytics_decorator, logging_decorator, log_public_functions_calls_using
+from platform_services_lib.lib.adapters.pagination_adapters import Paginator
+from platform_services_lib.lib.services.dlc_attributes_dict import AttributesDict
 
 
 @log_public_functions_calls_using(
@@ -19,15 +17,6 @@ class DictionaryModel(AttributesDict):
     def id(self):
         return self.dictionary_id
 
-    @property
-    def schema_id(self):
-        """This method is deprecated. Please use DictionaryModel.id"""
-        warnings.warn(
-            'This method is deprecated. Please use DictionaryModel.id',
-            DeprecationWarning
-        )
-        return self.id
-
     @property
     def fields(self):
 
