@@ -3,38 +3,31 @@
 # All Rights Reserved
 #
 import textwrap
-import warnings
 from collections import OrderedDict
 from typing import Dict
 
-from dli.client import utils
-from dli.models.paginator import Paginator
-from dli.client.components.urls import package_urls
-from dli.models import AttributesDict
+import dli.models
 from dli.models.dataset_model import DatasetModel
 
+from platform_services_lib.lib.adapters.pagination_adapters import Paginator
+from platform_services_lib.lib.services.dlc_attributes_dict import AttributesDict
+from platform_services_lib.lib.context.urls import package_urls
+
 
 class PackageModel(AttributesDict):
     """
-    Represents a package pulled back from Me consumables
+    Represents a package
     """
 
     @classmethod
-    def _raw_dict(cls, v1_response):
-        return v1_response['properties']
+    def _from_v2_response_unsheathed(cls, response_json, page_size=None):
+        """
 
-    @classmethod
-    def _from_v1_response_to_v2(cls, v1_response):
-        response = cls._client.session.get(
-            package_urls.v2_package_by_id.format(
-                id=v1_response['properties']['packageId']
-            )
-        )
-        json = response.json()
-        return cls(json)
-
-    @classmethod
-    def _from_v2_response_unsheathed(cls, response_json):
+        :param response_json:
+        :param page_size: Unused value, added to keep the same interface as
+        datasetModel's _from_v2_response_unsheathed.
+        :return:
+        """
 
         return cls({
             'data': response_json
@@ -56,14 +49,14 @@ class PackageModel(AttributesDict):
         super().__init__(id=json['data']['id'], **json['data']['attributes'])
         self._paginator = Paginator(
             package_urls.v2_package_datasets.format(id=self.id),
-            self._client.DatasetFactory,
-            self._client.DatasetFactory._from_v2_response_unsheathed
+            self._client._DatasetFactory,
+            self._client._DatasetFactory._from_v2_response_unsheathed
         )
 
     @property
     def shape(self):
         """
-        :returns: Count the number of datasets.
+        :returns: The number of datasets within this package
         :rtype: Int
         """
         if self.__shape is None:
@@ -72,43 +65,66 @@ class PackageModel(AttributesDict):
 
     def datasets(self) -> Dict[str, DatasetModel]:
         """
-        :returns: Dictionary of datasets in a package.
-        :rtype: OrderedDict[id: str, DatasetModel]
+        :returns: Dictionary of datasets shortcodes mapping to the model of the respective dataset, for each in the package.
+        :rtype: OrderedDict[id: str, dli.models.dataset_model.DatasetModel]
         """
         return OrderedDict([
             (v.short_code, v) for v in self._paginator
         ])
 
     def contents(self):
-        """Print information about all the datasets in this package."""
+        """Print each of the datasets in this package.
+
+          :Example:
+
+            .. code:: python
+
+                >>> p1 = client.packages.get('example')
+                >>> p1.contents()
+
+                DATASET "Paint Colours Palettes" [PARQUET]
+                >> Shortcode: PaintColours
+                >> Available Date Range: 2020-05-13 to 2020-05-13
+                >> ID: 804002d8-2466-4303-a470-3cb73f6def77
+                >> Published: Monthly by Dulux Paints
+                >> Accessible: True
+
+                This dataset lists the in vogue colour palettes
+
+                --------------------------------------------------------------------------------
+                DATASET "Furniture Inventory" [CSV]
+                >> Shortcode: FurnitureInventory
+                >> Available Date Range: 2012-01-13 to 2020-05-13
+                >> ID: 804002d8-2466-4303-a470-3cb73f6aaab7
+                >> Published: Daily by Furniture 4 You
+                >> Accessible: True
+
+                This dataset lists the currently in-stock furniture available to be purchase
+                from the wholesaler for decorators and designers
+
+                --------------------------------------------------------------------------------
+        """
         for p in self.datasets().items():
             print(str(p[1]))
 
     def metadata(self):
         """
         Once you have selected a package, you can print the metadata
-        (the available fields and values).
+        (the available fields and values). These are the attributes and their values for this package as listed on this page
 
         :example:
 
             .. code-block:: python
-                # Get all packages.
-                >>> packages = client.packages('example package')
-                # Get metadata of the 'example package' package.
-                >>> packages['example package'].metadata()
 
-        :example:
-
-            .. code-block:: python
                 # Get all packages with a name containing the text 'example package'. Filtering
                 # is done on the server side.
                 >>> packages = client.packages('example package')
                 # Get metadata of the 'example package' package.
                 >>> packages['example package'].metadata()
 
-        :return: Prints the metadata.
+        :return: Prints the metadata (attributes) keys and values.
         """
-        utils.print_model_metadata(self)
+        dli.models.print_model_metadata(self)
 
     def __str__(self):
         separator = "-"*80
