@@ -6,12 +6,13 @@ import itertools
 import logging
 import re
 from functools import partial
-from typing import Optional, List, Union, Tuple
+from typing import Optional, List, Union
 
-from dli.client.aspects import analytics_decorator, logging_decorator
-from dli.models import log_public_functions_calls_using
 from dli.models.dataset_model import DatasetModel
 
+from platform_services_lib.lib.aspects.decorators import analytics_decorator, logging_decorator, log_public_functions_calls_using
+from platform_services_lib.lib.handlers.s3_dataset_handler import S3PathDetails
+
 trace_logger = logging.getLogger('trace_logger')
 
 
@@ -100,6 +101,7 @@ class UnstructuredDatasetModel(DatasetModel):
     def __str__(self):
         return f"UNSTRUCTURED DATASET \"{self.short_code}\""
 
+    # nonstatic
     def _type_exception_handler(self, exception, func, args, kwargs):
         """
         Needed by aspects.py in order to throw a custom message if the
@@ -120,13 +122,13 @@ class UnstructuredDatasetModel(DatasetModel):
         with_documents: bool,
         document_types: Optional[Union[str, List[str]]],
         skip_folders_with_zero_matching_documents: bool,
-        paths: List[Tuple[str, int]]
-    ) -> List[Tuple[str, int]]:
+        paths: List[S3PathDetails]
+    ) -> List[S3PathDetails]:
         re_attachments = re.compile("^[^/]+\/[^/]+\/attachment\/.*")
         re_metadata = re.compile("^[^/]+\/[^/]+\/metadata\/.*")
         re_documents = re.compile("^[^/]+\/[^/]+\/document\/.*")
 
-        get_path = lambda x: x[0]
+        get_path = lambda x: x["Key"]
 
         if not with_attachments:
             paths = filter(
@@ -237,10 +239,8 @@ class UnstructuredDatasetModel(DatasetModel):
         * The name of any partition within the path is exactly the word
         `metadata`.
         * It is a directory rather than a file.
-        * Files with the wrong extension for the dataset's type i.e for
-        a .parquet dataset we will return only .parquet files,
-        zero .csv
-        files.
+        * Files with the wrong extension for the dataset's type i.e for a .parquet dataset we will return
+        only .parquet files, zero .csv files.
 
         Parameters
         ----------
@@ -254,7 +254,7 @@ class UnstructuredDatasetModel(DatasetModel):
             relative path (this is useful if using a TransferManager).
 
         :param bool skip_hidden_files: True (default) skips files
-        that have
+            that have
             been uploaded to S3 by Spark jobs. These usually start
             with a
             `.` or `_`.
